@@ -2,6 +2,7 @@ package cmd
 
 import (
 	"fmt"
+	"net"
 	"os"
 	"os/signal"
 	"path/filepath"
@@ -45,6 +46,7 @@ Run 'colima template' to set the default configurations or 'colima start --edit'
 		"  colima start --arch aarch64\n" +
 		"  colima start --dns 1.1.1.1 --dns 8.8.8.8\n" +
 		"  colima start --dns-host example.com=1.2.3.4\n" +
+		"  colima start --gateway-address 192.168.6.2\n" +
 		"  colima start --kubernetes --k3s-arg='\"--disable=coredns,servicelb,traefik,local-storage,metrics-server\"'",
 	Args: cobra.MaximumNArgs(1),
 	RunE: func(cmd *cobra.Command, args []string) error {
@@ -155,7 +157,12 @@ func init() {
 	}
 
 	mounts := strings.Join([]string{defaultMountTypeQEMU, "9p", "virtiofs"}, ", ")
-	types := strings.Join([]string{"qemu", "vz"}, ", ")
+
+	vmTypes := []string{"qemu", "vz"}
+	if util.MacOS13OrNewerOnArm() {
+		vmTypes = append(vmTypes, "krunkit")
+	}
+	types := strings.Join(vmTypes, ", ")
 
 	saveConfigDefault := true
 	if envSaveConfig.Exists() {
@@ -177,7 +184,7 @@ func init() {
 	startCmd.Flags().BoolVar(&startCmdArgs.Flags.Template, "template", true, "use the template file for initial configuration")
 
 	// port forwarder
-	startCmd.Flags().StringVar(&startCmdArgs.PortForwarder, "port-forwarder", "ssh", "port forwarder to use (ssh, grpc)")
+	startCmd.Flags().StringVar(&startCmdArgs.PortForwarder, "port-forwarder", "ssh", "port forwarder to use (ssh, grpc, none)")
 
 	// retain cpu flag for backward compatibility
 	startCmd.Flags().IntVar(&startCmdArgs.Flags.LegacyCPU, "cpu", defaultCPU, "number of CPUs")
@@ -210,6 +217,9 @@ func init() {
 		}
 	}
 
+	// Gateway Address
+	startCmd.Flags().IPVar(&startCmdArgs.Network.GatewayAddress, "gateway-address", net.ParseIP("192.168.5.2"), "gateway address")
+
 	// binfmt
 	startCmd.Flags().BoolVar(&startCmdArgs.Flags.Binfmt, "binfmt", true, binfmtDesc)
 
@@ -219,7 +229,7 @@ func init() {
 	startCmd.Flags().BoolVar(&startCmdArgs.Flags.SaveConfig, "save-config", saveConfigDefault, "persist and overwrite config file with (newly) specified flags")
 
 	// mounts
-	startCmd.Flags().StringSliceVarP(&startCmdArgs.Flags.Mounts, "mount", "V", nil, "directories to mount, suffix ':w' for writable")
+	startCmd.Flags().StringSliceVarP(&startCmdArgs.Flags.Mounts, "mount", "V", nil, "directories to mount, suffix ':w' for writable, disable with 'none'")
 	startCmd.Flags().StringVar(&startCmdArgs.MountType, "mount-type", defaultMountType, "volume driver for the mount ("+mounts+")")
 	startCmd.Flags().BoolVar(&startCmdArgs.MountINotify, "mount-inotify", true, "propagate inotify file events to the VM")
 
@@ -267,6 +277,12 @@ func dnsHostsFromFlag(hosts []string) map[string]string {
 func mountsFromFlag(mounts []string) []config.Mount {
 	mnts := make([]config.Mount, len(mounts))
 	for i, mount := range mounts {
+
+		// if one of the parameters is none, treat as none.
+		if strings.ToLower(mount) == "none" {
+			return nil
+		}
+
 		str := strings.SplitN(mount, ":", 3)
 		mnt := config.Mount{Location: str[0]}
 
@@ -302,7 +318,7 @@ func setFlagDefaults(cmd *cobra.Command) {
 	// mount type
 	{
 		// convert mount type for qemu
-		if startCmdArgs.VMType != "vz" && startCmdArgs.MountType == defaultMountTypeVZ {
+		if startCmdArgs.VMType != "vz" && startCmdArgs.VMType != "krunkit" && startCmdArgs.MountType == defaultMountTypeVZ {
 			startCmdArgs.MountType = defaultMountTypeQEMU
 			if cmd.Flag("mount-type").Changed {
 				log.Warnf("%s is only available for 'vz' vmType, using %s", defaultMountTypeVZ, defaultMountTypeQEMU)
@@ -325,6 +341,15 @@ func setFlagDefaults(cmd *cobra.Command) {
 			}
 		}
 	}
+
+	// always enable network address for incus, if supported and not explicitly disabled
+	if util.MacOS13OrNewer() {
+		if !cmd.Flag("network-address").Changed {
+			if startCmdArgs.Runtime == incus.Name && startCmdArgs.VMType == "vz" {
+				startCmdArgs.Network.Address = true
+			}
+		}
+	}
 }
 
 func setConfigDefaults(conf *config.Config) {
@@ -518,6 +543,9 @@ func prepareConfig(cmd *cobra.Command) {
 	if !cmd.Flag("dns-host").Changed {
 		startCmdArgs.Network.DNSHosts = current.Network.DNSHosts
 	}
+	if !cmd.Flag("gateway-address").Changed {
+		startCmdArgs.Network.GatewayAddress = current.Network.GatewayAddress
+	}
 	if !cmd.Flag("env").Changed {
 		startCmdArgs.Env = current.Env
 	}
