@@ -13,7 +13,7 @@ var stopCmdArgs struct {
 var stopCmd = &cobra.Command{
 	Use:   "stop [profile]",
 	Short: "stop Colima",
-	Long: `Stop stops Colima to free up resources.
+	Long: `Stop Colima to free up resources.
 
 The state of the VM is persisted at stop. A start afterwards
 should return it back to its previous state.`,
