@@ -88,6 +88,7 @@ type Network struct {
 	Mode            string            `yaml:"mode"` // shared, bridged
 	BridgeInterface string            `yaml:"interface"`
 	PreferredRoute  bool              `yaml:"preferredRoute"`
+	GatewayAddress  net.IP            `yaml:"gatewayAddress"`
 }
 
 // Mount is volume mount
@@ -97,11 +98,23 @@ type Mount struct {
 	Writable   bool   `yaml:"writable"`
 }
 
+// Provision modes managed by Colima (not passed to Lima).
+const (
+	ProvisionModeAfterBoot = "after-boot"
+	ProvisionModeReady     = "ready"
+)
+
 type Provision struct {
 	Mode   string `yaml:"mode"`
 	Script string `yaml:"script"`
 }
 
+// IsColimaMode returns true if the provision script is managed by Colima
+// rather than being passed to Lima.
+func (p Provision) IsColimaMode() bool {
+	return p.Mode == ProvisionModeAfterBoot || p.Mode == ProvisionModeReady
+}
+
 func (c Config) MountsOrDefault() []Mount {
 	if len(c.Mounts) > 0 {
 		return c.Mounts
@@ -126,6 +139,8 @@ func (c Config) Empty() bool { return c.Runtime == "" } // this may be better bu
 func (c Config) DriverLabel() string {
 	if util.MacOS13OrNewer() && c.VMType == "vz" {
 		return "macOS Virtualization.Framework"
+	} else if util.MacOS13OrNewerOnArm() && c.VMType == "krunkit" {
+		return "Krunkit"
 	}
 	return "QEMU"
 }
