@@ -2,6 +2,7 @@ package configmanager
 
 import (
 	"fmt"
+	"net"
 	"os"
 	"strings"
 
@@ -49,7 +50,7 @@ func LoadFrom(file string) (config.Config, error) {
 // ValidateConfig validates config before we use it
 func ValidateConfig(c config.Config) error {
 	validMountTypes := map[string]bool{"9p": true, "sshfs": true}
-	validPortForwarders := map[string]bool{"grpc": true, "ssh": true}
+	validPortForwarders := map[string]bool{"grpc": true, "ssh": true, "none": true}
 
 	if util.MacOS13OrNewer() {
 		validMountTypes["virtiofs"] = true
@@ -61,6 +62,12 @@ func ValidateConfig(c config.Config) error {
 	if util.MacOS13OrNewer() {
 		validVMTypes["vz"] = true
 	}
+	if util.MacOS13OrNewerOnArm() {
+		validVMTypes["krunkit"] = true
+	}
+	if c.VMType == "krunkit" && !util.MacOS13OrNewerOnArm() {
+		return fmt.Errorf("vmType 'krunkit' is only available on macOS with Apple Silicon")
+	}
 	if _, ok := validVMTypes[c.VMType]; !ok {
 		return fmt.Errorf("invalid vmType: '%s'", c.VMType)
 	}
@@ -69,6 +76,11 @@ func ValidateConfig(c config.Config) error {
 			return fmt.Errorf("cannot use vmType: '%s', error: %w", c.VMType, err)
 		}
 	}
+	if c.VMType == "krunkit" {
+		if err := util.AssertKrunkit(); err != nil {
+			return fmt.Errorf("cannot use vmType: '%s', error: %w", c.VMType, err)
+		}
+	}
 
 	if c.DiskImage != "" {
 		if strings.HasPrefix(c.DiskImage, "http://") || strings.HasPrefix(c.DiskImage, "https://") {
@@ -80,6 +92,12 @@ func ValidateConfig(c config.Config) error {
 		return fmt.Errorf("invalid port forwarder: '%s'", c.PortForwarder)
 	}
 
+	if c.Network.GatewayAddress != nil {
+		if err := validateGatewayAddress(c.Network.GatewayAddress); err != nil {
+			return err
+		}
+	}
+
 	return nil
 }
 
@@ -108,3 +126,19 @@ func Teardown() error {
 	}
 	return nil
 }
+
+// Validates that gateway is a valid IPv4 address and that the last octet is “2”.
+// Lima uses the last octet as 2 for gateways.
+func validateGatewayAddress(gateway net.IP) error {
+	ip4 := gateway.To4()
+	if ip4 == nil {
+		return fmt.Errorf("gateway %q is not IPv4", gateway)
+	}
+
+	// Check last octet
+	if ip4[3] != 2 {
+		return fmt.Errorf("the last octet of gateway %q is not 2", gateway)
+	}
+
+	return nil
+}
