@@ -111,7 +111,8 @@ func (l *limaVM) Start(ctx context.Context, conf config.Config) error {
 		return yamlutil.WriteYAML(l.limaConf, confFile)
 	})
 
-	a.Add(l.writeNetworkFile)
+	a.Add(func() error { return l.writeNetworkFile(conf) })
+
 	a.Add(func() error {
 		return l.host.Run(limactl, "start", "--tty=false", confFile)
 	})
@@ -166,7 +167,7 @@ func (l *limaVM) resume(ctx context.Context, conf config.Config) error {
 		return err
 	})
 
-	a.Add(l.writeNetworkFile)
+	a.Add(func() error { return l.writeNetworkFile(conf) })
 
 	a.Stage("starting")
 	a.Add(func() error {
@@ -210,6 +211,8 @@ func (l limaVM) Stop(ctx context.Context, force bool) error {
 
 	a.Add(func() error { l.removeHostAddresses(); return nil })
 
+	a.Add(func() error { l.removeIncusContainerRoute(); return nil })
+
 	a.Add(func() error {
 		if force {
 			return l.host.Run(limactl, "stop", "--force", config.CurrentProfile().ID)
@@ -305,7 +308,7 @@ func (l *limaVM) addPostStartActions(a *cli.ActiveCommandChain, conf config.Conf
 			}
 		}
 
-		if l.limaConf.Rosetta.Enabled {
+		if l.limaConf.VMOpts.VZOpts.Rosetta.Enabled {
 			// enable rosetta
 			err := l.Run("sudo", "sh", "-c", `stat /proc/sys/fs/binfmt_misc/rosetta || echo ':rosetta:M::\x7fELF\x02\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x3e\x00:\xff\xff\xff\xff\xff\xfe\xfe\x00\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xff\xff\xff:/mnt/lima-rosetta/rosetta:OCF' > /proc/sys/fs/binfmt_misc/register`)
 			if err != nil {
